@@ -10,7 +10,7 @@ if os.path.isdir(DIR):
 
 import unittest
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import RPCProxy, CONTEXT, SOCK, test_view
+from trytond.tests.test_tryton import test_view
 
 
 class PurchaseInvoiceLineStandaloneTestCase(unittest.TestCase):
@@ -30,13 +30,10 @@ class PurchaseInvoiceLineStandaloneTestCase(unittest.TestCase):
             'purchase_invoice_line_standalone'))
 
 def suite():
-    return unittest.TestLoader().loadTestsFromTestCase(
-            PurchaseInvoiceLineStandaloneTestCase)
+    suite = trytond.tests.test_tryton.suite()
+    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
+            PurchaseInvoiceLineStandaloneTestCase))
+    return suite
 
 if __name__ == '__main__':
-    suiteTrytond = trytond.tests.test_tryton.suite()
-    suitePurchaseInvoiceLineStandalone = suite()
-    alltests = unittest.TestSuite([suiteTrytond,
-        suitePurchaseInvoiceLineStandalone])
-    unittest.TextTestRunner(verbosity=2).run(alltests)
-    SOCK.disconnect()
+    unittest.TextTestRunner(verbosity=2).run(suite())
